@@ -1,4 +1,4 @@
-/* $EPIC: irc.c,v 1.757 2007/09/18 02:31:47 jnelson Exp $ */
+/* $EPIC: irc.c,v 1.777 2014/02/11 20:42:38 jnelson Exp $ */
 /*
  * ircII: a new irc client.  I like it.  I hope you will too!
  *
@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC4-2.8";
-const char useful_info[] = "epic4 2 8 0";
+const char irc_version[] = "EPIC4-2.10.4";
+const char useful_info[] = "epic4 2 10 4";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20070916";
+const char internal_version[] = "20080904";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 759;
+const unsigned long	commit_id = 778;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 759;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Officious";
+const char ridiculous_version_name[] = "Induration";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -71,7 +71,7 @@ const char ridiculous_version_name[] = "Officious";
 #include "input.h"
 #include "alias.h"
 #include "output.h"
-#include "term.h"
+#include "termx.h"
 #include "exec.h"
 #include "screen.h"
 #include "log.h"
@@ -815,6 +815,17 @@ static	void	parse_args (int argc, char **argv)
 	return;
 }
 
+/* fire scripted signal events -pegasus */
+void do_signals(void)
+{
+	int sig_no;
+
+	signals_caught[0] = 0;
+	for (sig_no = 0; sig_no < NSIG; sig_no++)
+		while (signals_caught[sig_no])
+			do_hook(SIGNAL_LIST, "%d %d", sig_no, signals_caught[sig_no]--);
+}
+
 /* 
  * io() is a ONE TIME THROUGH loop!  It simply does ONE check on the
  * file descriptors, and if there is nothing waiting, it will time
@@ -933,6 +944,8 @@ static 	const Timeval	right_away = { 0, 0 };
 		} 
 	}
 
+	if (signals_caught[0] != 0)
+		do_signals();
 	ExecuteTimers();
 	get_child_exit(-1);
 	if (level == 1 && need_defered_commands)
@@ -1139,6 +1152,14 @@ int 	main (int argc, char *argv[])
 	if (!use_input && fork())
 		_exit(0);
 
+	/* make sure we don't start with spurious signals events firing */
+	memset(&signals_caught, 0, NSIG * sizeof(int));
+	/* hook all signals! */
+	init_signals();
+	/* we *might* want to check for SIG_ERR from the above function.
+	 * i leave it to hop to decide what to do on SIG_ERR. -pegasus 
+	 */
+
 	/* these should be taken by both dumb and smart displays */
 	my_signal(SIGSEGV, coredump);
 	my_signal(SIGBUS, coredump);
